ApiKeyResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

ApiKeyResponse([void updates(ApiKeyResponseBuilder b)])
factory

Properties

allowedScopes → BuiltList<String>?
no setter
clientName String
no setter
createdAt DateTime
no setter
description String?
no setter
environmentId String?
no setter
expiresAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
isActive bool
no setter
isExpired bool
no setter
isValid bool
no setter
keyPrefix String
no setter
lastUsedAt DateTime?
no setter
projectId String?
no setter
revokedAt DateTime?
no setter
role String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usageCount int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ApiKeyResponseBuilder)) ApiKeyResponse
Rebuilds the instance.
inherited
toBuilder() ApiKeyResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ApiKeyResponse>
no setter