AuthDiagnostics class abstract

Annotations
  • @BuiltValue.new()

Constructors

AuthDiagnostics([void updates(AuthDiagnosticsBuilder b)])
factory

Properties

configuredKeycloakUrl String?
no setter
expectedIssuer String?
no setter
hasAuthorizationHeader bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isAuthenticated bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenAudience String?
no setter
tokenClaims → BuiltList<String>
no setter
tokenIssuer String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AuthDiagnosticsBuilder)) AuthDiagnostics
Rebuilds the instance.
inherited
toBuilder() AuthDiagnosticsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AuthDiagnostics>
no setter