BellaBaxterFeaturesNotificationsTestNotificationChannelApi class
Constructors
- BellaBaxterFeaturesNotificationsTestNotificationChannelApi(Dio _dio, Serializers _serializers)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
testNotificationChannel(
{required String id, CancelToken? cancelToken, Map< String, dynamic> ? headers, Map<String, dynamic> ? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) → Future<Response< NotificationChannelOperationResponse> > - POST_api_v1_notifications_id_test POST_api_v1_notifications_id_test
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited