BellaBaxterFeaturesProjectsEnvironmentsGetEnvironmentProvidersApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEnvironmentProviders({required String projectRef, required String envSlug, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<BuiltList<EnvironmentProviderResponse>>>
-
GET_api_v1_projects_projectRef_environments_envSlug_providers
GET_api_v1_projects_projectRef_environments_envSlug_providers
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited