BellaBaxterFeaturesProjectsEnvironmentsSecretsUploadSecretsFileApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
uploadSecretsFile({required String projectRef, required String envSlug, required String providerSlug, required MultipartFile file, bool? overwriteExisting, String? typeOverrides, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<UploadSecretsFileResponse>>
-
POST_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_upload
POST_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_upload