BellaBaxterFeaturesProjectsGroupsAssignGroupToProjectApi class

Constructors

BellaBaxterFeaturesProjectsGroupsAssignGroupToProjectApi(Dio _dio, Serializers _serializers)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignGroupToProject({required String projectRef, required AssignGroupToProjectRequest assignGroupToProjectRequest, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<OperationResponse>>
POST_api_v1_projects_projectRef_groups POST_api_v1_projects_projectRef_groups
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited