BellaBaxterFeaturesProjectsRemoveProjectUserApi class

Constructors

BellaBaxterFeaturesProjectsRemoveProjectUserApi(Dio _dio, Serializers _serializers)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeUserFromProject({required String projectRef, required String userId, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<OperationResponse>>
DELETE_api_v1_projects_projectRef_users_userId DELETE_api_v1_projects_projectRef_users_userId
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited