BellaBaxterFeaturesProvidersUpdateProviderApi class

Constructors

BellaBaxterFeaturesProvidersUpdateProviderApi(Dio _dio, Serializers _serializers)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateProvider({required String id, required UpdateProviderCommand updateProviderCommand, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<ProviderOperationResponse>>
PUT_api_v1_providers_id PUT_api_v1_providers_id

Operators

operator ==(Object other) bool
The equality operator.
inherited