BellaBaxterFeaturesSecurityIntelligenceGetProjectSecurityApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getProjectSecurity({required String projectSlug, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<ProjectSecurityResponse>>
-
GET_api_v1_projects_projectSlug_security
GET_api_v1_projects_projectSlug_security
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited