CopyEnvironmentCommand class abstract

CopyEnvironmentCommand

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CopyEnvironmentCommand([void updates(CopyEnvironmentCommandBuilder b)])
factory

Properties

copyProviders → bool?
no setter
copySecretKeys → bool?
no setter
description → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CopyEnvironmentCommandBuilder)) → CopyEnvironmentCommand
Rebuilds the instance.
inherited
toBuilder() → CopyEnvironmentCommandBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CopyEnvironmentCommand>
no setter