CopyEnvironmentResponse class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- CopyEnvironmentResponse([void updates(CopyEnvironmentResponseBuilder b)])
-
factory
Properties
- environment → EnvironmentResponse
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setter
- providersAssigned → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKeysCreated → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CopyEnvironmentResponseBuilder)) → CopyEnvironmentResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → CopyEnvironmentResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
CopyEnvironmentResponse> -
no setter