CreateApiKeyRequest class abstract

CreateApiKeyRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateApiKeyRequest([void updates(CreateApiKeyRequestBuilder b)])
factory

Properties

clientName String
no setter
description String?
no setter
expiresInDays int?
no setter
hashCode int
The hash code for this object.
no setterinherited
publicKey String?
no setter
role String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateApiKeyRequestBuilder)) CreateApiKeyRequest
Rebuilds the instance.
inherited
toBuilder() CreateApiKeyRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateApiKeyRequest>
no setter