CreateInviteCommand class abstract

CreateInviteCommand

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateInviteCommand([void updates(CreateInviteCommandBuilder b)])
factory

Properties

email → String?
no setter
expiresInDays → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
role → TenantInviteRole?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeId → String?
no setter
scopeKind → TenantInviteScopeKind?
no setter
scopeRole → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateInviteCommandBuilder)) → CreateInviteCommand
Rebuilds the instance.
inherited
toBuilder() → CreateInviteCommandBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateInviteCommand>
no setter