CreateInviteCommandBuilder class

Properties

email ↔ String?
getter/setter pair
expiresInDays ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
role ↔ TenantInviteRole?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeId ↔ String?
getter/setter pair
scopeKind ↔ TenantInviteScopeKind?
getter/setter pair
scopeRole ↔ String?
getter/setter pair

Methods

build() → CreateInviteCommand
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CreateInviteCommand other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CreateInviteCommandBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited