CreateOwnTenantCommand class abstract

CreateOwnTenantCommand

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateOwnTenantCommand([void updates(CreateOwnTenantCommandBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateOwnTenantCommandBuilder)) CreateOwnTenantCommand
Rebuilds the instance.
inherited
toBuilder() CreateOwnTenantCommandBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateOwnTenantCommand>
no setter