CreateSecretRequest class abstract

CreateSecretRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateSecretRequest([void updates(CreateSecretRequestBuilder b)])
factory

Properties

description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
ignoreInScan bool?
no setter
key String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter
value String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateSecretRequestBuilder)) CreateSecretRequest
Rebuilds the instance.
inherited
toBuilder() CreateSecretRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateSecretRequest>
no setter