CreateShareCommand class abstract

CreateShareCommand

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateShareCommand([void updates(CreateShareCommandBuilder b)])
factory

Properties

ciphertext String
no setter
expiresAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
iv String
no setter
label String
no setter
maxViews int?
no setter
passwordHash String?
no setter
passwordSalt String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateShareCommandBuilder)) CreateShareCommand
Rebuilds the instance.
inherited
toBuilder() CreateShareCommandBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateShareCommand>
no setter