CreateShareResponse class abstract

CreateShareResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateShareResponse([void updates(CreateShareResponseBuilder b)])
factory

Properties

expiresAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPassword bool
no setter
label String
no setter
maxViews int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateShareResponseBuilder)) CreateShareResponse
Rebuilds the instance.
inherited
toBuilder() CreateShareResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateShareResponse>
no setter