CreateTenantResponse class abstract

CreateTenantResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

CreateTenantResponse([void updates(CreateTenantResponseBuilder b)])
factory

Properties

domain String?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
no setter
tenantId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CreateTenantResponseBuilder)) CreateTenantResponse
Rebuilds the instance.
inherited
toBuilder() CreateTenantResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CreateTenantResponse>
no setter