CurrentUserResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

CurrentUserResponse([void updates(CurrentUserResponseBuilder b)])
factory

Properties

createdAt DateTime
no setter
email String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
isAdmin bool
no setter
nombre String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenRemainingMinutes int
no setter
updatedAt DateTime?
no setter
username String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CurrentUserResponseBuilder)) CurrentUserResponse
Rebuilds the instance.
inherited
toBuilder() CurrentUserResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CurrentUserResponse>
no setter