EnvironmentProviderResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

EnvironmentProviderResponse([void updates(EnvironmentProviderResponseBuilder b)])
factory

Properties

assignedAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
providerDescription String?
no setter
providerId String
no setter
providerMetaType String
no setter
providerName String
no setter
providerSlug String
no setter
providerType String
no setter
region String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(EnvironmentProviderResponseBuilder)) EnvironmentProviderResponse
Rebuilds the instance.
inherited
toBuilder() EnvironmentProviderResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<EnvironmentProviderResponse>
no setter