EnvironmentResponse class abstract
EnvironmentResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- EnvironmentResponse([void updates(EnvironmentResponseBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
no setter
- creatorId → String?
-
no setter
- creatorUsername → String?
-
no setter
- currentUserRole → String?
-
no setter
- description → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- memberCount → int
-
no setter
- name → String
-
no setter
- projectId → String
-
no setter
- projectName → String?
-
no setter
- providerCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretCount → int
-
no setter
- slug → String
-
no setter
- status → String?
-
no setter
- updatedAt → DateTime
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(EnvironmentResponseBuilder)) → EnvironmentResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → EnvironmentResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
EnvironmentResponse> -
no setter