EnvironmentUserResponse class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- EnvironmentUserResponse([void updates(EnvironmentUserResponseBuilder b)])
-
factory
Properties
- assignedAt → DateTime
-
no setter
- email → String?
-
no setter
- fullName → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- role → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
no setter
- username → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(EnvironmentUserResponseBuilder)) → EnvironmentUserResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → EnvironmentUserResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
EnvironmentUserResponse> -
no setter