GenerateCredentialsCommand class abstract

GenerateCredentialsCommand

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GenerateCredentialsCommand([void updates(GenerateCredentialsCommandBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
role String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlSeconds int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GenerateCredentialsCommandBuilder)) GenerateCredentialsCommand
Rebuilds the instance.
inherited
toBuilder() GenerateCredentialsCommandBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GenerateCredentialsCommand>
no setter