GenerateCredentialsResponse class abstract

GenerateCredentialsResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GenerateCredentialsResponse([void updates(GenerateCredentialsResponseBuilder b)])
factory

Properties

connectionUrl String?
no setter
expiresAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
leaseDurationSeconds int
no setter
leaseId String
no setter
password String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GenerateCredentialsResponseBuilder)) GenerateCredentialsResponse
Rebuilds the instance.
inherited
toBuilder() GenerateCredentialsResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GenerateCredentialsResponse>
no setter