GetTenantResponse class abstract

GetTenantResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GetTenantResponse([void updates(GetTenantResponseBuilder b)])
factory

Properties

createdAt DateTime
no setter
domain String?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
no setter
status TenantStatus
no setter
tenantId String
no setter
updatedAt DateTime
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetTenantResponseBuilder)) GetTenantResponse
Rebuilds the instance.
inherited
toBuilder() GetTenantResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetTenantResponse>
no setter