ImportSecretsRequest class abstract

ImportSecretsRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ImportSecretsRequest([void updates(ImportSecretsRequestBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keys → BuiltList<String>?
no setter
overwriteExisting bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceProviderId String
no setter
typeOverrides → BuiltMap<String, String>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ImportSecretsRequestBuilder)) ImportSecretsRequest
Rebuilds the instance.
inherited
toBuilder() ImportSecretsRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ImportSecretsRequest>
no setter