IssueEnvironmentTokenRequest class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- IssueEnvironmentTokenRequest([void updates(IssueEnvironmentTokenRequestBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ BuiltList<
String> -
no setter
- ttlMinutes → int?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(IssueEnvironmentTokenRequestBuilder)) → IssueEnvironmentTokenRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → IssueEnvironmentTokenRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
IssueEnvironmentTokenRequest> -
no setter