KeyContextResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

KeyContextResponse([void updates(KeyContextResponseBuilder b)])
factory

Properties

environmentId String?
no setter
environmentName String?
no setter
environmentSlug String?
no setter
hashCode int
The hash code for this object.
no setterinherited
keyId String
no setter
projectId String?
no setter
projectName String?
no setter
projectSlug String?
no setter
role String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String?
no setter
tenantName String?
no setter
tenantSlug String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(KeyContextResponseBuilder)) KeyContextResponse
Rebuilds the instance.
inherited
toBuilder() KeyContextResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<KeyContextResponse>
no setter