LeaseResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

LeaseResponse([void updates(LeaseResponseBuilder b)])
factory

Properties

expiredAt DateTime?
no setter
expiresAt DateTime
no setter
grantedAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
holderId String
no setter
holderName String
no setter
id String
no setter
revocationReason String?
no setter
revokedAt DateTime?
no setter
revokedBy String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretCount int
no setter
secretKeysSnapshot → BuiltList<String>
no setter
status String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LeaseResponseBuilder)) LeaseResponse
Rebuilds the instance.
inherited
toBuilder() LeaseResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<LeaseResponse>
no setter