NotificationChannelOperationResponse class abstract

NotificationChannelOperationResponse

Properties:

Annotations
  • @BuiltValue.new()

Properties

channel NotificationChannelResponse?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(NotificationChannelOperationResponseBuilder)) NotificationChannelOperationResponse
Rebuilds the instance.
inherited
toBuilder() NotificationChannelOperationResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<NotificationChannelOperationResponse>
no setter