ProblemDetails class abstract

ProblemDetails

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ProblemDetails([void updates(ProblemDetailsBuilder b)])
factory

Properties

detail → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int?
no setter
title → String?
no setter
type → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ProblemDetailsBuilder)) → ProblemDetails
Rebuilds the instance.
inherited
toBuilder() → ProblemDetailsBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ProblemDetails>
no setter