ProjectImportResponseBuilder class
Constructors
Properties
- environmentsCreated ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- projectId ↔ String?
-
getter/setter pair
- projectSlug ↔ String?
-
getter/setter pair
- providersMatched ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success ↔ bool?
-
getter/setter pair
-
warnings
↔ ListBuilder<
String> -
getter/setter pair
Methods
-
build(
) → ProjectImportResponse -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
ProjectImportResponse other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(ProjectImportResponseBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited