ProjectOperationResponse class abstract

ProjectOperationResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ProjectOperationResponse([void updates(ProjectOperationResponseBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
no setter
project ProjectResponse?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter
timestamp DateTime
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ProjectOperationResponseBuilder)) ProjectOperationResponse
Rebuilds the instance.
inherited
toBuilder() ProjectOperationResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ProjectOperationResponse>
no setter