ProjectResponseBuilder class

Constructors

ProjectResponseBuilder()

Properties

createdAt DateTime?
getter/setter pair
currentUserRole String?
getter/setter pair
deletedAt DateTime?
getter/setter pair
description String?
getter/setter pair
environmentCount int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
memberCount int?
getter/setter pair
name String?
getter/setter pair
ownerId String?
getter/setter pair
ownerName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretCount int?
getter/setter pair
slug String?
getter/setter pair
status String?
getter/setter pair
tags ↔ ListBuilder<String>
getter/setter pair
updatedAt DateTime?
getter/setter pair

Methods

build() ProjectResponse
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ProjectResponse other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(ProjectResponseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited