RecoverEncryptionKeyResponse class abstract

RecoverEncryptionKeyResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

RecoverEncryptionKeyResponse([void updates(RecoverEncryptionKeyResponseBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
no setter
newMasterKeyFingerprint String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RecoverEncryptionKeyResponseBuilder)) RecoverEncryptionKeyResponse
Rebuilds the instance.
inherited
toBuilder() RecoverEncryptionKeyResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RecoverEncryptionKeyResponse>
no setter