SecretManifestItem class abstract

SecretManifestItem

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SecretManifestItem([void updates(SecretManifestItemBuilder b)])
factory

Properties

description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
key String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SecretManifestItemBuilder)) SecretManifestItem
Rebuilds the instance.
inherited
toBuilder() SecretManifestItemBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SecretManifestItem>
no setter