SecurityInsight class abstract

Annotations
  • @BuiltValue.new()

Constructors

SecurityInsight([void updates(SecurityInsightBuilder b)])
factory

Properties

detail String
no setter
hashCode int
The hash code for this object.
no setterinherited
matchedPattern String?
no setter
recommendation String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
no setter
severity SecurityRiskLevel
no setter
type SecurityInsightType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SecurityInsightBuilder)) SecurityInsight
Rebuilds the instance.
inherited
toBuilder() SecurityInsightBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SecurityInsight>
no setter