SshCreateRoleRequest class abstract

SshCreateRoleRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SshCreateRoleRequest([void updates(SshCreateRoleRequestBuilder b)])
factory

Properties

allowedUsers String
no setter
defaultTtl String?
no setter
hashCode int
The hash code for this object.
no setterinherited
maxTtl String?
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SshCreateRoleRequestBuilder)) SshCreateRoleRequest
Rebuilds the instance.
inherited
toBuilder() SshCreateRoleRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SshCreateRoleRequest>
no setter