TotpKeyListItem class abstract

TotpKeyListItem

Properties:

Annotations
  • @BuiltValue.new()

Constructors

TotpKeyListItem([void updates(TotpKeyListItemBuilder b)])
factory

Properties

accountName String?
no setter
algorithm String
no setter
digits int
no setter
hashCode int
The hash code for this object.
no setterinherited
issuer String?
no setter
name String
no setter
period int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TotpKeyListItemBuilder)) TotpKeyListItem
Rebuilds the instance.
inherited
toBuilder() TotpKeyListItemBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TotpKeyListItem>
no setter