UpdateApiKeyStatusRequest class abstract

UpdateApiKeyStatusRequest

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UpdateApiKeyStatusRequest([void updates(UpdateApiKeyStatusRequestBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpdateApiKeyStatusRequestBuilder)) UpdateApiKeyStatusRequest
Rebuilds the instance.
inherited
toBuilder() UpdateApiKeyStatusRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateApiKeyStatusRequest>
no setter