UpdateTrustDomainCommand class abstract

Annotations
  • @BuiltValue.new()

Constructors

UpdateTrustDomainCommand([void updates(UpdateTrustDomainCommandBuilder b)])
factory

Properties

claimRules → BuiltList<ClaimRule>?
no setter
description String?
no setter
grantedRole String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool?
no setter
issuedTokenTtlMinutes int?
no setter
name String?
no setter
oidcIssuerUrl String?
no setter
oidcJwksUri String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UpdateTrustDomainCommandBuilder)) UpdateTrustDomainCommand
Rebuilds the instance.
inherited
toBuilder() UpdateTrustDomainCommandBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UpdateTrustDomainCommand>
no setter