UploadSecretsFileResponse class abstract

UploadSecretsFileResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UploadSecretsFileResponse([void updates(UploadSecretsFileResponseBuilder b)])
factory

Properties

failed → BuiltList<UploadFailure>
no setter
hashCode → int
The hash code for this object.
no setterinherited
imported → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UploadSecretsFileResponseBuilder)) → UploadSecretsFileResponse
Rebuilds the instance.
inherited
toBuilder() → UploadSecretsFileResponseBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UploadSecretsFileResponse>
no setter