UserRoleAssignment class abstract

UserRoleAssignment

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UserRoleAssignment([void updates(UserRoleAssignmentBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
role String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserRoleAssignmentBuilder)) UserRoleAssignment
Rebuilds the instance.
inherited
toBuilder() UserRoleAssignmentBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserRoleAssignment>
no setter