AccessLogEntry class abstract
AccessLogEntry
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- AccessLogEntry([void updates(AccessLogEntryBuilder b)])
-
factory
Properties
- action → String
-
no setter
- actorType → String
-
no setter
- apiKeyId → String?
-
no setter
- apiKeyName → String?
-
no setter
- appClient → String?
-
no setter
- city → String?
-
no setter
- country → String?
-
no setter
- detail → String?
-
no setter
- environmentId → String
-
no setter
- environmentSlug → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- ipAddress → String
-
no setter
- projectId → String
-
no setter
- projectSlug → String
-
no setter
- providerId → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKey → String?
-
no setter
- timestamp → DateTime
-
no setter
- userAgent → String?
-
no setter
- userId → String?
-
no setter
- userName → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AccessLogEntryBuilder)) → AccessLogEntry -
Rebuilds the instance.
inherited
-
toBuilder(
) → AccessLogEntryBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AccessLogEntry> -
no setter