DriftSummary class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- DriftSummary([void updates(DriftSummaryBuilder b)])
-
factory
Properties
- driftedKeys → int
-
no setter
- envSpecificKeys → int
-
no setter
- globalKeys → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalKeys → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DriftSummaryBuilder)) → DriftSummary -
Rebuilds the instance.
inherited
-
toBuilder(
) → DriftSummaryBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DriftSummary> -
no setter