LeaseResponseBuilder class
Constructors
Properties
- expiredAt ↔ DateTime?
-
getter/setter pair
- expiresAt ↔ DateTime?
-
getter/setter pair
- grantedAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- holderId ↔ String?
-
getter/setter pair
- holderName ↔ String?
-
getter/setter pair
- id ↔ String?
-
getter/setter pair
- revocationReason ↔ String?
-
getter/setter pair
- revokedAt ↔ DateTime?
-
getter/setter pair
- revokedBy ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretCount ↔ int?
-
getter/setter pair
-
secretKeysSnapshot
↔ ListBuilder<
String> -
getter/setter pair
- status ↔ String?
-
getter/setter pair
Methods
-
build(
) → LeaseResponse -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
LeaseResponse other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(LeaseResponseBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited