MigrateTenantEncryptionResponse class abstract
MigrateTenantEncryptionResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- MigrateTenantEncryptionResponse([void updates(MigrateTenantEncryptionResponseBuilder b)])
-
factory
Properties
- environmentsProcessed → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setter
- notificationsEncrypted → int
-
no setter
- projectsProcessed → int
-
no setter
- providersEncrypted → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretsEncrypted → int
-
no setter
- secretsSkipped → int
-
no setter
- success → bool
-
no setter
- webhooksEncrypted → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(MigrateTenantEncryptionResponseBuilder)) → MigrateTenantEncryptionResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → MigrateTenantEncryptionResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
MigrateTenantEncryptionResponse> -
no setter