PageProjectResponse class abstract
PageProjectResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- PageProjectResponse([void updates(PageProjectResponseBuilder b)])
-
factory
Properties
-
content
→ BuiltList<
ProjectResponse> -
no setter
- empty → bool
-
no setter
- first → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- last → bool
-
no setter
- number → int
-
no setter
- numberOfElements → int
-
no setter
- pageable → PageableObject
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setter
- sort → SortObject
-
no setter
- totalElements → int
-
no setter
- totalPages → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PageProjectResponseBuilder)) → PageProjectResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → PageProjectResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PageProjectResponse> -
no setter