ProjectGlobalSecurityReportBuilder class
Constructors
Properties
- breachCheckSkipped ↔ bool?
-
getter/setter pair
- critical ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- high ↔ int?
-
getter/setter pair
-
insights
↔ ListBuilder<
SecurityInsight> -
getter/setter pair
- low ↔ int?
-
getter/setter pair
- medium ↔ int?
-
getter/setter pair
- noProviderConfigured ↔ bool?
-
getter/setter pair
- overallRisk ↔ String?
-
getter/setter pair
- providerFetchFailed ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannedAt ↔ DateTime?
-
getter/setter pair
- totalSecretsScanned ↔ int?
-
getter/setter pair
Methods
-
build(
) → ProjectGlobalSecurityReport -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
ProjectGlobalSecurityReport other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(ProjectGlobalSecurityReportBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited