ProjectImportResponse class abstract
ProjectImportResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- ProjectImportResponse([void updates(ProjectImportResponseBuilder b)])
-
factory
Properties
- environmentsCreated → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setter
- projectId → String
-
no setter
- projectSlug → String
-
no setter
- providersMatched → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
no setter
-
warnings
→ BuiltList<
String> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ProjectImportResponseBuilder)) → ProjectImportResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → ProjectImportResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ProjectImportResponse> -
no setter