ProjectResponse class abstract

Annotations
  • @BuiltValue.new()

Constructors

ProjectResponse([void updates(ProjectResponseBuilder b)])
factory

Properties

createdAt DateTime
no setter
currentUserRole String?
no setter
deletedAt DateTime?
no setter
description String?
no setter
environmentCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
memberCount int
no setter
name String
no setter
ownerId String
no setter
ownerName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretCount int
no setter
slug String
no setter
status String
no setter
tags → BuiltList<String>?
no setter
updatedAt DateTime?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ProjectResponseBuilder)) ProjectResponse
Rebuilds the instance.
inherited
toBuilder() ProjectResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ProjectResponse>
no setter