ProviderResponse class abstract
ProviderResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- ProviderResponse([void updates(ProviderResponseBuilder b)])
-
factory
Properties
-
configuration
→ BuiltMap<
String, String> -
no setter
- createdAt → DateTime
-
no setter
- createdBy → String
-
no setter
- deletedAt → DateTime?
-
no setter
- description → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- metaType → String
-
no setter
- name → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
no setter
- source_ → String
-
no setter
- status → String
-
no setter
- type → String
-
no setter
- updatedAt → DateTime?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ProviderResponseBuilder)) → ProviderResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → ProviderResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ProviderResponse> -
no setter