TenantEncryptionKeyStatusResponse class abstract

Annotations
  • @BuiltValue.new()

Properties

encryptionEnabled bool
no setter
enforceZke bool
no setter
hasDek bool
no setter
hashCode int
The hash code for this object.
no setterinherited
masterKeyFingerprint String?
no setter
recoveryKeyFingerprint String?
no setter
registeredAt DateTime?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TenantEncryptionKeyStatusResponseBuilder)) TenantEncryptionKeyStatusResponse
Rebuilds the instance.
inherited
toBuilder() TenantEncryptionKeyStatusResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TenantEncryptionKeyStatusResponse>
no setter