WebhookResponse class abstract
WebhookResponse
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- WebhookResponse([void updates(WebhookResponseBuilder b)])
-
factory
Properties
- autoRotateDays → int?
-
no setter
- createdAt → DateTime
-
no setter
- createdBy → String
-
no setter
- environmentId → String?
-
no setter
-
eventTypes
→ BuiltList<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- isActive → bool
-
no setter
- keyPrefix → String
-
no setter
- linkedEnvironmentId → String?
-
no setter
- linkedKeyName → String?
-
no setter
- name → String
-
no setter
- nextRotationAt → DateTime?
-
no setter
- projectId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetUrl → String
-
no setter
- updatedAt → DateTime?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(WebhookResponseBuilder)) → WebhookResponse -
Rebuilds the instance.
inherited
-
toBuilder(
) → WebhookResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
WebhookResponse> -
no setter